@@ -47,7 +47,7 @@ class Xvfb:
         self.environ = environ or os.environ
 
         if not self._xvfb_exists():
-            raise OSError("Can't find Xvfb. Please install it and try again")
+            raise OSError("Could not find Xvfb. Please install it and try again")
 
         self.xvfb_cmd = []
         self.extra_xvfb_args = [
@@ -74,9 +74,13 @@ class Xvfb:
         self.stop()
 
     def start(self) -> None:
+        if not os.access(self._tempdir, os.W_OK):
+            raise RuntimeError(
+                f"Could not access writable temp directory: {self._tempdir}"
+            )
         if self.new_display is not None:
             if not self._get_lock_for_display(self.new_display):
-                raise ValueError(f"Could not lock display :{self.new_display}")
+                raise RuntimeError(f"Could not lock display :{self.new_display}")
         else:
             self.new_display = self._get_next_unused_display()
         display_var = f":{self.new_display}"
@@ -168,7 +172,11 @@ class Xvfb:
                 return rand
 
     def _local_display_exists(self, display) -> bool:
-        return Path("/tmp", ".X11-unix", f"X{display}").exists()
+        tempdir = "/tmp"
+        # We need read access to the real system temp directory
+        if not os.access(tempdir, os.R_OK):
+            raise RuntimeError(f"Could not access {tempdir} directory: {self._tempdir}")
+        return Path(tempdir, ".X11-unix", f"X{display}").exists()
 
     def _set_display(self, display_var):
         self.environ["DISPLAY"] = display_var
